rnalysis.filtering.FoldChangeFilter.filter\_abs\_log2\_fold\_change
===================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: FoldChangeFilter.filter_abs_log2_fold_change